@@ -20,7 +20,6 @@ class lazy_property(object):
     :raises: :class:`LazyPropertyException`
     """
     def __init__(self, func=None):
-
         self._func = func
         self.__doc__ = func.__doc__
         self.__name__ = func.__name__
@@ -42,7 +41,7 @@ class lazy_property(object):
         elif myname in instance.__dict__:
             return self._func(instance)
         else:
-            if getattr(instance, instance.primary_key) is not None:
+            if getattr(instance, instance.PRIMARY_KEY) is not None:
                 try:
                     instance.load()
                 except AttributeError as detail:
@@ -57,6 +56,12 @@ class lazy_property(object):
         if self._sfunc is None:
             raise TypeError, "immutable attribute: %s" % self.__name__
         else:
+            try:
+                old_val = getattr(instance, self.__name__)
+            except AttributeError:
+                # This is okay in cases where we're instantiating a new resource
+                old_val = None
+            instance.track_change(self.__name__, old_val, value)
             self._sfunc(instance, value)
 
     def setter(self, sfunc):
