@@ -2,9 +2,9 @@ from mixcoatl.resource import Resource
 from mixcoatl.decorators.lazy import lazy_property
 
 class FirewallRule(Resource):
-    path = 'network/FirewallRule'
-    collection_name = 'rules'
-    primary_key = 'firewall_rule_id'
+    PATH = 'network/FirewallRule'
+    COLLECTION_NAME = 'rules'
+    PRIMARY_KEY = 'firewall_rule_id'
 
     def __init__(self, firewall_rule_id = None, *args, **kwargs):
         Resource.__init__(self)
@@ -13,7 +13,7 @@ class FirewallRule(Resource):
     @property
     def firewall_rule_id(self):
         return self.__firewall_rule_id
-    
+
     @lazy_property
     def direction(self):
         return self.__direction
@@ -33,12 +33,12 @@ class FirewallRule(Resource):
     @classmethod
     def all(cls, firewall_id):
         from mixcoatl.utils import uncamel_keys
-        r = Resource(cls.path)
+        r = Resource(cls.PATH)
         r.request_details = 'extended'
         params = {'firewallId':firewall_id}
         c = r.get(params=params)
         if r.last_error is None:
-            rules = [i['firewallRuleId'] for i in c[cls.collection_name]]
+            rules = [i['firewallRuleId'] for i in c[cls.COLLECTION_NAME]]
             return [cls(rule) for rule in rules]
         else:
-            return r.last_error
\ No newline at end of file
+            return r.last_error
